@@ -12,7 +12,7 @@
 from __future__ import absolute_import, unicode_literals
 import sys
 
-from .client import LineClient, LineGroup, LineContact
+from .client import LineClient, LineGroup, LineContact, LineRoom
 
-__version__ = '0.0.8'
-__all__ = ['LineClient','LineGroup','LineContact']
+__version__ = '0.1.0'
+__all__ = ['LineClient','LineRoom', 'LineGroup','LineContact']
