@@ -204,7 +204,7 @@ class LineGroup(LineBase):
             for member in group.invitee:
                 self.invitee.append(LineContact(client, member))
 
-    def leaveGroup(self):
+    def leave(self):
         """Leave group"""
         try:
             self._client._leaveGroup(self.id)
@@ -216,6 +216,39 @@ class LineGroup(LineBase):
         """Name of Group and number of group members"""
         return '<LineGroup %s #%s>' % (self.name, len(self.members))
 
+class LineRoom(LineBase):
+    """Chat room wrapper
+    
+    Attributes:
+        contacts           Contact list of chat room
+    """
+    def __init__(self, client, room):
+        """LineContact init
+
+        :param client: LineClient instance
+        :param room: Room instace
+        """
+
+        self._client  = client
+        self._room = room 
+
+        self.id = room.mid
+
+        self.contacts = []
+        for contact in room.contacts:
+            self.contacts.append(LineContact(client, contact))
+
+    def leave(self):
+        """Leave room"""
+        try:
+            self._client._leaveRoom(self.id)
+            return True
+        except:
+            return False
+
+    def __repr__(self):
+        return '<LineRoom %s>' % (self.contacts)
+
 class LineContact(LineBase):
     """LineContact wrapper
     
@@ -321,6 +354,7 @@ class LineClient(object):
         self.revision = self._getLastOpRevision()
         self.refreshContacts()
         self.refreshGroups()
+        self.refreshActiveRooms()
 
     def ready(self):
         """
@@ -389,8 +423,29 @@ class LineClient(object):
             msg = "require device confirm"
             self.raise_error(msg)
 
+    def refreshActiveRooms(self):
+        """Refresh active chat rooms"""
+        if self.check_auth():
+            start = 1
+            count = 50
+
+            self.rooms = []
+
+            while True:
+                channel = self._getMessageBoxCompactWrapUpList(start, count)
+
+                for box in channel.messageBoxWrapUpList:
+                    if box.messageBox.midType == ToType.ROOM:
+                        room = LineRoom(self, self._getRoom(box.messageBox.id))
+                        self.rooms.append(room)
+
+                if len(channel.messageBoxWrapUpList) == count:
+                    start += count
+                else:
+                    break
+
     def refreshGroups(self):
-        """Refresh groups of LineClient """
+        """Refresh groups of LineClient"""
         if self.check_auth():
             group_ids = self._getGroupIdsJoined()
             groups    = self._getGroups(group_ids)
@@ -402,12 +457,6 @@ class LineClient(object):
 
             self.groups.sort()
 
-    def refreshRooms(self):
-        """Refresh rooms. Need to be called after `refreshContacts`"""
-        if self.check_auth():
-            for contact in self.contacts:
-                messageBox = self.getMessageBox(contact.id)
-
     def refreshContacts(self):
         """Refresh contacts of LineClient """
         if self.check_auth():
@@ -463,43 +512,114 @@ class LineClient(object):
 
         return None
 
-    def getMessageBox(self, id):
-        try:
-            messageBoxWrapUp = self._client._getMessageBoxCompactWrapUp(self.id)
+    def createRoomWithIds(self, ids=[]):
+        """Create a chat room with contact ids"""
+        if self.check_auth():
+            try:
+                room = LineRoom(self, self._createRoom(ids))
+                self.rooms.append(room)
 
-            return messageBoxWrapUp.messageBox
-        except:
-            return None
+                return room
+            except Exception as e:
+                self.raise_error(e)
+
+                return None
+
+    def createRoomWithContacts(self, contacts=[]):
+        """Create a chat room with contacts"""
+        if self.check_auth():
+            try:
+                contact_ids = []
+                for contact in contacts:
+                    contact_ids.append(contact.id)
+
+                room = LineRoom(self, self._createRoom(contact_ids))
+                self.rooms.append(room)
+
+                return room
+            except Exception as e:
+                self.raise_error(e)
+
+                return None
+
+    def createGroupWithIds(self, ids=[]):
+        """Create a group with contact ids
+
+        :param name: name of group
+        :param ids: list of contact ids
+        """
+        if self.check_auth():
+            try:
+                group = LineGroup(self, self._createGroup(name, ids))
+                self.groups.append(group)
+
+                return group
+            except Exception as e:
+                self.raise_error(e)
+
+                return None
+
+    def createGroupWithContacts(self, name, contacts=[]):
+        """Create a group with contacts
+        
+        :param name: name of group
+        :param contacts: list of contacts
+        """
+        if self.check_auth():
+            try:
+                contact_ids = []
+                for contact in contacts:
+                    contact_ids.append(contact.id)
+
+                group = LineGroup(self, self._createGroup(name, contact_ids))
+                self.groups.append(group)
+
+                return group
+            except Exception as e:
+                self.raise_error(e)
+
+                return None
+
+
+    def getMessageBox(self, id):
+        if self.check_auth():
+            try:
+                messageBoxWrapUp = self._client._getMessageBoxCompactWrapUp(self.id)
+
+                return messageBoxWrapUp.messageBox
+            except:
+                return None
 
     def longPoll(self, count=50):
-        """Check is there any operations from LINE server"""
-        OT = CurveThrift.OperationType
+        if self.check_auth():
+            """Check is there any operations from LINE server"""
+            OT = CurveThrift.OperationType
 
-        try:
-            operations = self._client_in.fetchOperations(self.revision, count)
-        except EOFError:
-            return
-        except TalkException as e:
-            if e.code == 9:
-                raise_error("user logged in to another machien")
-            else:
+            try:
+                operations = self._client_in.fetchOperations(self.revision, count)
+            except EOFError:
                 return
+            except TalkException as e:
+                if e.code == 9:
+                    raise_error("user logged in to another machien")
+                else:
+                    return
 
-        for operation in operations:
-            if operation.type == OT.END_OF_OPERATION:
-                pass
-            elif operation.type == OT.SEND_MESSAGE:
-                pass
-            elif operation.type == OT.RECEIVE_MESSAGE:
-                message = LineMessage(self, operation.message)
-                group_or_contact = self.getContactOrGroupFromId(message.to)
+            for operation in operations:
+                if operation.type == OT.END_OF_OPERATION:
+                    pass
+                elif operation.type == OT.SEND_MESSAGE:
+                    pass
+                elif operation.type == OT.RECEIVE_MESSAGE:
+                    message = LineMessage(self, operation.message)
+                    group_or_contact = self.getContactOrGroupFromId(message.to)
 
-                yield (group_or_contact, message)
-            else:
-                print "[*] %s" % OT._VALUES_TO_NAMES[operation.type]
-                print operation
+                    yield (group_or_contact, message)
+                else:
+                    print "[*] %s" % OT._VALUES_TO_NAMES[operation.type]
+                    print operation
 
-            self.revision = max(operation.revision, self.revision)
+                self.revision = max(operation.revision, self.revision)
 
     def raise_error(self, msg):
         """Fix a error format"""
@@ -542,6 +662,11 @@ class LineClient(object):
         if self.check_auth():
             return self._client.getAllContactIds()
 
+    def _getBlockedContactIds(self):
+        """Get all blocked contacts of your LINE account"""
+        if self.check_auth():
+            return self._client.getBlockedContactIds()
+
     def _getContacts(self, ids):
         """Get contact information list from ids
         
@@ -572,12 +697,28 @@ class LineClient(object):
         if self.check_auth():
             return self._client.getContacts(ids)
 
-    def _getGroupIdsJoined(self):
-        """Get group id that you joined"""
+    def _createRoom(self, ids, seq=0):
+        """Create a chat room"""
         if self.check_auth():
-            return self._client.getGroupIdsJoined()
+            return self._client.createRoom(seq, ids)
+
+    def _getRoom(self, id):
+        """Get a chat room"""
+        if self.check_auth():
+            return self._client.getRoom(id)
+
+    def _leaveRoom(self, id):
+        """Leave a chat room"""
+        if self.check_auth():
+            return self._client.leaveRoom(0, id)
+
+    def _createGroup(self, name, ids, seq=0):
+        """Create a group"""
+        if self.check_auth():
+            return self._client.createGroup(seq, name, ids)
 
     def _getGroups(self, ids):
+        """Get a list of group with ids"""
         if type(ids) != list:
             msg = "argument should be list of group ids"
             raise_error(msg)
@@ -585,6 +726,16 @@ class LineClient(object):
         if self.check_auth():
             return self._client.getGroups(ids)
 
+    def _getGroupIdsJoined(self):
+        """Get group id that you joined"""
+        if self.check_auth():
+            return self._client.getGroupIdsJoined()
+
+    def _getGroupIdsInvited(self):
+        """Get group id that you invited"""
+        if self.check_auth():
+            return self._client.getGroupIdsInvited()
+
     def _leaveGroup(self, id):
         """Leave a group"""
         if self.check_auth():
@@ -616,7 +767,13 @@ class LineClient(object):
         if self.check_auth():
             try:
                 return self._client.getMessageBoxCompactWrapUp(id)
+            except:
+                return None
+
+    def _getMessageBoxCompactWrapUpList(self, start=1, count=50):
+        if self.check_auth():
+            try:
+                return self._client.getMessageBoxCompactWrapUpList(start, count)
             except Exception as e:
                 msg = e
                 raise_error(msg)
-
